use std::path::PathBuf;

use actix_files::NamedFile;
use actix_web::middleware::Logger;
use actix_web::{get, web::Data, App, HttpRequest, HttpResponse, HttpServer, Responder, Result};
use env_logger::Env;
use tera::{Context, Tera};

struct AppData {
    tmpl: Tera,
}

#[get("/")]
async fn index(data: Data<AppData>, req: HttpRequest) -> impl Responder {
    let mut ctx = Context::new();

    let rendered = data.tmpl.render("templates/index.html", &ctx).unwrap();
    HttpResponse::Ok().body(rendered)
}

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    env_logger::init_from_env(
        Env::default()
            .default_filter_or("info")
            .default_filter_or("debug"),
    );

    HttpServer::new(|| {
        App::new()
            .service(index)
            .service(actix_files::Files::new("/resources", ".").show_files_listing())
            .service(actix_files::Files::new("/templates", ".").show_files_listing())
            .app_data(Data::new(AppData {
                tmpl: Tera::new("/templates/**/*").unwrap(),
            }))
            .wrap(Logger::default())
    })
    .bind(("127.0.0.1", 8080))?
    .run()
    .await
}
